[X2Go-Commits] x2gobroker.git - build-main (branch) updated: fbde70cbb12c5687ee3e4597a782fc25a86d8011

X2Go dev team git-admin at x2go.org
Sun May 19 13:04:27 CEST 2013


The branch, build-main has been updated
       via  fbde70cbb12c5687ee3e4597a782fc25a86d8011 (commit)
      from  e1c3ba9271e5c7cb8223c698b14f90469906c157 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
-----------------------------------------------------------------------

Summary of changes:
 Makefile                                           |    6 +++---
 debian/control                                     |    6 ++++--
 ...ver-broker.install => x2gobroker-agent.install} |    0
 lib/{x2gobroker-command.pl => x2gobroker-agent.pl} |    0
 src/{x2gobroker-command.c => x2gobroker-agent.c}   |   10 +++++-----
 5 files changed, 12 insertions(+), 10 deletions(-)
 rename debian/{x2goserver-broker.install => x2gobroker-agent.install} (100%)
 rename lib/{x2gobroker-command.pl => x2gobroker-agent.pl} (100%)
 rename src/{x2gobroker-command.c => x2gobroker-agent.c} (87%)

The diff of changes is:
diff --git a/Makefile b/Makefile
index 058cf82..d7699c1 100755
--- a/Makefile
+++ b/Makefile
@@ -47,10 +47,10 @@ all: clean build
 
 build: build-arch build-indep
 
-build-arch: build_setgidwrappers
+build-arch: build_setuidwrappers
 
-build_setgidwrappers:
-	gcc -fPIE -pie -o lib/x2gobroker-command src/x2gobroker-command.c
+build_setuidwrappers:
+	gcc -fPIE -pie -o lib/x2gobroker-agent src/x2gobroker-agent.c
 
 build-indep:
 
diff --git a/debian/control b/debian/control
index b20d578..9f5cd0f 100644
--- a/debian/control
+++ b/debian/control
@@ -65,7 +65,7 @@ Description: X2Go http(s) session broker (simple broker)
  This package contains a simple example of an X2Go session
  broker.
 
-Package: x2goserver-broker
+Package: x2gobroker-agent
 Architecture: any
 Depends:
  ${misc:Depends},
@@ -90,7 +90,9 @@ Description: X2Go http(s) based session broker (common files)
  X2Go server farms.
  .
  This package contains a setuid backend command that
- is required by the X2Go session broker.
+ is required by the X2Go session broker. This package
+ has to be installed on all X2Go servers that shall get
+ controlled via the X2Go session broker.
  .
  WARNING: This package installs the setuid wrapper
  /usr/lib/x2go/broker/x2gobroker-command on your system.
diff --git a/debian/x2goserver-broker.install b/debian/x2gobroker-agent.install
similarity index 100%
rename from debian/x2goserver-broker.install
rename to debian/x2gobroker-agent.install
diff --git a/lib/x2gobroker-command.pl b/lib/x2gobroker-agent.pl
similarity index 100%
rename from lib/x2gobroker-command.pl
rename to lib/x2gobroker-agent.pl
diff --git a/src/x2gobroker-command.c b/src/x2gobroker-agent.c
similarity index 87%
rename from src/x2gobroker-command.c
rename to src/x2gobroker-agent.c
index 39526cf..29992fd 100644
--- a/src/x2gobroker-command.c
+++ b/src/x2gobroker-agent.c
@@ -29,7 +29,7 @@
 #include <errno.h>
 
 int main( int argc, char *argv[] ) {
-	char * x2gobrokercmdpl = NULL;
+	char * x2gobrokeragentpl = NULL;
 	size_t path_max;
 	
 /*
@@ -60,20 +60,20 @@ int main( int argc, char *argv[] ) {
 			exit(EXIT_FAILURE);
 		}
 
-		// derive the full path of x2gobroker-command.pl from path of this binary
-		rvap = asprintf(&x2gobrokercmdpl, "%s/%s", dirname(buffer), "x2gobroker-command.pl");
+		// derive the full path of x2gobroker-agent.pl from path of this binary
+		rvap = asprintf(&x2gobrokeragentpl, "%s/%s", dirname(buffer), "x2gobroker-agent.pl");
 		if(rvap == -1){
 			fprintf(stderr, "Failed to allocate memory calling asprintf\n");
 			exit(EXIT_FAILURE);
 		}
 
 		// execute the script, running with user-rights of this binary 
-		execv(x2gobrokercmdpl, argv);
+		execv(x2gobrokeragentpl, argv);
 
 	}
 
 	// ...fail
-	fprintf(stderr, "Failed to execute %s: %s\n", x2gobrokercmdpl, strerror(errno));
+	fprintf(stderr, "Failed to execute %s: %s\n", x2gobrokeragentpl, strerror(errno));
 	return EXIT_FAILURE;
 
 }


hooks/post-receive
-- 
x2gobroker.git (HTTP(S) Session broker for X2Go)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "x2gobroker.git" (HTTP(S) Session broker for X2Go).




More information about the x2go-commits mailing list